# <img src='https://raw.githack.com/FortAwesome/Font-Awesome/master/svgs/solid/life-ring.svg' card_color="#FF8600" width="50" style="vertical-align:bottom">Support Helper
  
## Summary  
Get diagnostic information sent via email.

## Description
The skill provides the functionality to get core module status information and 
message information, including user profile information, sent to the user via email.
  
## Examples
- "Create a troubleshooting package."
- "Create a support ticket."

## Troubleshooting
If you do not see your troubleshooting email, check your spam folder.

## Contact Support
Use the [link](https://neongecko.com/ContactUs) or [submit an issue on GitHub](https://help.github.com/en/articles/creating-an-issue)

## Credits
[NeonGeckoCom](https://github.com/NeonGeckoCom)
[NeonDaniel](https://github.com/NeonDaniel)
[reginaneon](https://github.com/reginaneon)

## Tags
#NeonGecko Original
#NeonAI
#Support
#Help